==> mongoctl-0.7.7.tar.gz: mongoctl-0.7.7/mongoctl/tests/test_suite.py <==
# The MIT License

# Copyright (c) 2012 ObjectLabs Corporation

# Permission is hereby granted, free of charge, to any person obtaining
# a copy of this software and associated documentation files (the
# "Software"), to deal in the Software without restriction, including
# without limitation the rights to use, copy, modify, merge, publish,
# distribute, sublicense, and/or sell copies of the Software, and to
# permit persons to whom the Software is furnished to do so, subject to
# the following conditions:

# The above copyright notice and this permission notice shall be
# included in all copies or substantial portions of the Software.

# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
# EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
# MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
# NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE
# LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION
# OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION
# WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.


import unittest

from version_functions_test import VersionFunctionsTest
from basic_test import BasicMongoctlTest
from master_slave_test import MasterSlaveTest
from replicaset_test import ReplicasetTest
from misc_test import MiscTest
from auth_replicaset_test import AuthReplicasetTest

###############################################################################
all_suites = [
    unittest.TestLoader().loadTestsFromTestCase(VersionFunctionsTest),
    unittest.TestLoader().loadTestsFromTestCase(BasicMongoctlTest),
    unittest.TestLoader().loadTestsFromTestCase(MasterSlaveTest),
    unittest.TestLoader().loadTestsFromTestCase(ReplicasetTest),
    unittest.TestLoader().loadTestsFromTestCase(AuthReplicasetTest),
    unittest.TestLoader().loadTestsFromTestCase(MiscTest)
]
###############################################################################
# booty
###############################################################################
if __name__ == '__main__':
    unittest.TextTestRunner(verbosity=2).run(unittest.TestSuite(all_suites))

==> mongoctl-0.9.0.tar.gz: mongoctl-0.9.0/mongoctl/tests/test_suite.py <==
# The MIT License

# Copyright (c) 2012 ObjectLabs Corporation

# Permission is hereby granted, free of charge, to any person obtaining
# a copy of this software and associated documentation files (the
# "Software"), to deal in the Software without restriction, including
# without limitation the rights to use, copy, modify, merge, publish,
# distribute, sublicense, and/or sell copies of the Software, and to
# permit persons to whom the Software is furnished to do so, subject to
# the following conditions:

# The above copyright notice and this permission notice shall be
# included in all copies or substantial portions of the Software.

# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
# EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
# MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
# NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE
# LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION
# OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION
# WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.


import unittest

from version_functions_test import VersionFunctionsTest
from basic_test import BasicMongoctlTest
from master_slave_test import MasterSlaveTest
from replicaset_test import ReplicasetTest
from misc_test import MiscTest
from auth_replicaset_test import AuthReplicasetTest
from cmdline_servers_test import CommandlineServersTest
###############################################################################
all_suites = [
    unittest.TestLoader().loadTestsFromTestCase(VersionFunctionsTest),
    unittest.TestLoader().loadTestsFromTestCase(BasicMongoctlTest),
    unittest.TestLoader().loadTestsFromTestCase(MasterSlaveTest),
    unittest.TestLoader().loadTestsFromTestCase(ReplicasetTest),
    unittest.TestLoader().loadTestsFromTestCase(AuthReplicasetTest),
    unittest.TestLoader().loadTestsFromTestCase(MiscTest),
    unittest.TestLoader().loadTestsFromTestCase(CommandlineServersTest)
]
###############################################################################
# booty
###############################################################################
if __name__ == '__main__':
    unittest.TextTestRunner(verbosity=2).run(unittest.TestSuite(all_suites))
